@@ -2,6 +2,7 @@ import os
 import click
 
 from . import __version__
+from .translate import translate_file
 
 @click.command()
 @click.option("--update", "-u", is_flag=True)
@@ -13,4 +14,5 @@ def main(update, translate, filename):
         print('updating airtable cache')
     if translate:
         click.echo(click.format_filename(filename))
-        print(f'translating {filename} in {os.getcwd()}')
\ No newline at end of file
+        print(f'translating {filename} in {os.getcwd()}')
+        translate_file(filename)
\ No newline at end of file
